@@ -1,9 +1,9 @@
 /*
- * "$Id: ipp.c 6967 2007-09-17 23:30:52Z mike $"
+ * "$Id: ipp.c 7254 2008-01-23 22:23:42Z mike $"
  *
  *   IPP backend for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007 by Apple Inc.
+ *   Copyright 2007-2008 by Apple Inc.
  *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -236,6 +236,9 @@ main(int  argc,				/* I - Number of command-line args */
     return (CUPS_BACKEND_STOP);
   }
 
+  if (!port)
+    port = IPP_PORT;			/* Default to port 631 */
+
   if (!strcmp(method, "https"))
     cupsSetEncryption(HTTP_ENCRYPT_ALWAYS);
   else
@@ -518,8 +521,8 @@ main(int  argc,				/* I - Number of command-line args */
 	              _("INFO: Unable to contact printer, queuing on next "
 			"printer in class...\n"));
 
-        if (argc == 6 || strcmp(filename, argv[6]))
-	  unlink(filename);
+        if (tmpfilename[0])
+	  unlink(tmpfilename);
 
        /*
         * Sleep 5 seconds to keep the job from requeuing too rapidly...
@@ -576,8 +579,8 @@ main(int  argc,				/* I - Number of command-line args */
 
   if (job_cancelled)
   {
-    if (argc == 6 || strcmp(filename, argv[6]))
-      unlink(filename);
+    if (tmpfilename[0])
+      unlink(tmpfilename);
 
     return (CUPS_BACKEND_FAILED);
   }
@@ -762,8 +765,8 @@ main(int  argc,				/* I - Number of command-line args */
       ippDelete(supported);
       httpClose(http);
 
-      if (argc == 6 || strcmp(filename, argv[6]))
-	unlink(filename);
+      if (tmpfilename[0])
+	unlink(tmpfilename);
 
      /*
       * Sleep 5 seconds to keep the job from requeuing too rapidly...
@@ -862,12 +865,13 @@ main(int  argc,				/* I - Number of command-line args */
     num_options = cupsParseOptions(argv[5], 0, &options);
 
 #ifdef __APPLE__
-    if (!strcasecmp(content_type, "application/pictwps") && num_files == 1)
+    if (!strcasecmp(final_content_type, "application/pictwps") &&
+        num_files == 1)
     {
       if (format_sup != NULL)
       {
 	for (i = 0; i < format_sup->num_values; i ++)
-	  if (!strcasecmp(content_type, format_sup->values[i].string.text))
+	  if (!strcasecmp(final_content_type, format_sup->values[i].string.text))
 	    break;
       }
 
@@ -878,10 +882,18 @@ main(int  argc,				/* I - Number of command-line args */
 	* so convert the document to PostScript...
 	*/
 
-	if (run_pictwps_filter(argv, filename))
-	  return (CUPS_BACKEND_FAILED);
+	if (run_pictwps_filter(argv, files[0]))
+	{
+	  if (pstmpname[0])
+	    unlink(pstmpname);
 
-        filename = pstmpname;
+	  if (tmpfilename[0])
+	    unlink(tmpfilename);
+
+	  return (CUPS_BACKEND_FAILED);
+        }
+
+        files[0] = pstmpname;
 
        /*
 	* Change the MIME type to application/postscript and change the
@@ -1055,7 +1067,7 @@ main(int  argc,				/* I - Number of command-line args */
 
     _cupsLangPuts(stderr, _("INFO: Waiting for job to complete...\n"));
 
-    for (; !job_cancelled;)
+    for (delay = 1; !job_cancelled;)
     {
      /*
       * Build an IPP_GET_JOB_ATTRIBUTES request...
@@ -1146,10 +1158,14 @@ main(int  argc,				/* I - Number of command-line args */
       check_printer_state(http, uri, resource, argv[2], version, job_id);
 
      /*
-      * Wait 10 seconds before polling again...
+      * Wait 1-10 seconds before polling again...
       */
 
-      sleep(10);
+      sleep(delay);
+
+      delay ++;
+      if (delay > 10)
+        delay = 1;
     }
   }
 
@@ -1673,7 +1689,6 @@ run_pictwps_filter(char       **argv,	/* I - Command-line arguments */
 
     _cupsLangPrintf(stderr, _("ERROR: Unable to fork pictwpstops: %s\n"),
 		    strerror(errno));
-    unlink(filename);
     if (ppdfile)
       unlink(ppdfile);
     return (-1);
@@ -1688,7 +1703,6 @@ run_pictwps_filter(char       **argv,	/* I - Command-line arguments */
     _cupsLangPrintf(stderr, _("ERROR: Unable to wait for pictwpstops: %s\n"),
 		    strerror(errno));
     close(fd);
-    unlink(filename);
     if (ppdfile)
       unlink(ppdfile);
     return (-1);
@@ -1708,7 +1722,6 @@ run_pictwps_filter(char       **argv,	/* I - Command-line arguments */
       _cupsLangPrintf(stderr, _("ERROR: pictwpstops exited on signal %d!\n"),
 		      status);
 
-    unlink(filename);
     return (status);
   }
 
@@ -1758,5 +1771,5 @@ sigterm_handler(int sig)		/* I - Signal */
 
 
 /*
- * End of "$Id: ipp.c 6967 2007-09-17 23:30:52Z mike $".
+ * End of "$Id: ipp.c 7254 2008-01-23 22:23:42Z mike $".
  */
