@@ -1,5 +1,5 @@
 /*
- * "$Id: lpd.c 6911 2007-09-04 20:35:08Z mike $"
+ * "$Id: lpd.c 7067 2007-11-09 19:54:09Z mike $"
  *
  *   Line Printer Daemon backend for the Common UNIX Printing System (CUPS).
  *
@@ -201,6 +201,9 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
 		  hostname, sizeof(hostname), &port,
 		  resource, sizeof(resource));
 
+  if (!port)
+    port = 515;				/* Default to port 515 */
+
   if (!username[0])
   {
    /*
@@ -1315,5 +1318,5 @@ sigterm_handler(int sig)		/* I - Signal */
 
 
 /*
- * End of "$Id: lpd.c 6911 2007-09-04 20:35:08Z mike $".
+ * End of "$Id: lpd.c 7067 2007-11-09 19:54:09Z mike $".
  */
