@@ -1,7 +1,7 @@
 /*
-* "$Id: pap.c 6911 2007-09-04 20:35:08Z mike $"
+* "$Id: pap.c 7319 2008-02-15 23:26:51Z mike $"
 *
-*  Copyright 2004 Apple Computer, Inc. All rights reserved.
+* Copyright 2004-2008 Apple Inc. All rights reserved.
 * 
 * IMPORTANT:  This Apple software is supplied to you by Apple Computer,
 * Inc. ("Apple") in consideration of your agreement to the following
@@ -70,6 +70,16 @@
 *  signalHandler()	 - handle SIGINT to close the session before quiting.
 */
 
+/*
+ * This backend uses deprecated APIs for AppleTalk; we know this, so
+ * silence any warnings about it...
+ */
+
+#ifdef MAC_OS_X_VERSION_MIN_REQUIRED
+#  undef MAC_OS_X_VERSION_MIN_REQUIRED
+#endif /* MAX_OS_X_VERSION_MIN_REQUIRED */
+#define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_0
+
 #include <config.h>
 
 #include <stdio.h>
@@ -85,17 +95,17 @@
 #include <sys/time.h>
 #include <sys/errno.h>
 
+#include <cups/cups.h>
+#include <cups/backend.h>
+#include <cups/sidechannel.h>
+#include <cups/i18n.h>
+
 #include <netat/appletalk.h>
 #include <netat/atp.h>
 #include <netat/ddp.h>
 #include <netat/nbp.h>
 #include <netat/pap.h>
 
-#include <cups/cups.h>
-#include <cups/backend.h>
-#include <cups/sidechannel.h>
-#include <cups/i18n.h>
-
 #include <libkern/OSByteOrder.h>
 
 #ifdef HAVE_APPLETALK_AT_PROTO_H
@@ -207,12 +217,7 @@ int main (int argc, const char * argv[])
 
   if (argc == 1 || (argc == 2 && strcmp(argv[1], "-discover") == 0))
   {
-    /* If listDevices() didn't find any devices or returns an error output a 
-    *  legacy style announcement.
-    *  
-    */
-    if (listDevices() <= 0)
-      puts("network pap \"Unknown\" \"AppleTalk Printer Access Protocol (pap)\"");
+    listDevices();
 
     return 0;
   }
@@ -291,7 +296,7 @@ static int listDevices(void)
   /* Make sure it's okay to use appletalk */
   if (!okayToUseAppleTalk())
   {
-    fprintf(stderr, "ERROR: AppleTalk disabled in System Preferences\n");
+    fprintf(stderr, "INFO: AppleTalk disabled in System Preferences\n");
     return -1;  /* Network is down */
   }
 
