@@ -1,9 +1,9 @@
 /*
- * "$Id: runloop.c 6835 2007-08-22 18:34:34Z mike $"
+ * "$Id: runloop.c 7205 2008-01-09 19:00:02Z mike $"
  *
  *   Common run loop APIs for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007 by Apple Inc.
+ *   Copyright 2007-2008 by Apple Inc.
  *   Copyright 2006-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -216,7 +216,7 @@ backendRunLoop(
       FD_SET(CUPS_SC_FD, &input);
 
     FD_ZERO(&output);
-    if (print_bytes || !use_bc)
+    if (print_bytes || (!use_bc && !side_cb))
       FD_SET(device_fd, &output);
 
     if (use_bc || side_cb)
@@ -374,5 +374,5 @@ backendRunLoop(
 
 
 /*
- * End of "$Id: runloop.c 6835 2007-08-22 18:34:34Z mike $".
+ * End of "$Id: runloop.c 7205 2008-01-09 19:00:02Z mike $".
  */
