@@ -1,8 +1,9 @@
 /*
- * "$Id: scsi-irix.c 5241 2006-03-07 22:07:44Z mike $"
+ * "$Id: scsi-irix.c 6835 2007-08-22 18:34:34Z mike $"
  *
  *   IRIX SCSI printer support for the Common UNIX Printing System (CUPS).
  *
+ *   Copyright 2007 by Apple Inc.
  *   Copyright 2003-2005 by Easy Software Products, all rights reserved.
  *
  *   Redistribution and use in source and binary forms, with or
@@ -95,7 +96,8 @@ print_device(const char *resource,	/* I - SCSI device */
 
   if (strncmp(resource, "/dev/scsi/", 10) != 0)
   {
-    fprintf(stderr, "ERROR: Bad SCSI device file \"%s\"!\n", resource);
+    _cupsLangPrintf(stderr, _("ERROR: Bad SCSI device file \"%s\"!\n"),
+                    resource);
     return (CUPS_BACKEND_STOP);
   }
 
@@ -118,8 +120,9 @@ print_device(const char *resource,	/* I - SCSI device */
 	* available printer in the class.
 	*/
 
-        fputs("INFO: Unable to open SCSI device, queuing on next printer in class...\n",
-	      stderr);
+        _cupsLangPuts(stderr,
+	              _("INFO: Unable to contact printer, queuing on next "
+			"printer in class...\n"));
 
        /*
         * Sleep 5 seconds to keep the job from requeuing too rapidly...
@@ -132,14 +135,15 @@ print_device(const char *resource,	/* I - SCSI device */
 
       if (errno != EAGAIN && errno != EBUSY)
       {
-	fprintf(stderr, "ERROR: Unable to open SCSI device \"%s\" - %s\n",
-        	resource, strerror(errno));
+	_cupsLangPrintf(stderr,
+	                _("ERROR: Unable to open device file \"%s\": %s\n"),
+			resource, strerror(errno));
 	return (CUPS_BACKEND_FAILED);
       }
       else
       {
-        fprintf(stderr, "INFO: SCSI device \"%s\" busy; retrying...\n",
-	        resource);
+        _cupsLangPuts(stderr,
+	              _("INFO: Printer busy; will retry in 30 seconds...\n"));
         sleep(30);
       }
     }
@@ -201,8 +205,9 @@ print_device(const char *resource,	/* I - SCSI device */
 	if (ioctl(scsi_fd, DS_ENTER, &scsi_req) < 0 ||
             scsi_req.ds_status != 0)
         {
-	  fprintf(stderr, "WARNING: SCSI command timed out (%d); retrying...\n",
-	          scsi_req.ds_status);
+	  _cupsLangPrintf(stderr,
+			  _("WARNING: SCSI command timed out (%d); "
+			    "retrying...\n"), scsi_req.ds_status);
           sleep(try + 1);
 	}
 	else
@@ -210,8 +215,8 @@ print_device(const char *resource,	/* I - SCSI device */
 
       if (try >= 10)
       {
-	fprintf(stderr, "ERROR: Unable to send print data (%d)\n",
-	        scsi_req.ds_status);
+	_cupsLangPrintf(stderr, _("ERROR: Unable to send print data (%d)\n"),
+			scsi_req.ds_status);
         close(scsi_fd);
 	return (CUPS_BACKEND_FAILED);
       }
@@ -231,5 +236,5 @@ print_device(const char *resource,	/* I - SCSI device */
 
 
 /*
- * End of "$Id: scsi-irix.c 5241 2006-03-07 22:07:44Z mike $".
+ * End of "$Id: scsi-irix.c 6835 2007-08-22 18:34:34Z mike $".
  */
