@@ -1,5 +1,5 @@
 /*
- * "$Id: usb-unix.c 6911 2007-09-04 20:35:08Z mike $"
+ * "$Id: usb-unix.c 7406 2008-03-26 16:02:45Z mike $"
  *
  *   USB port backend for the Common UNIX Printing System (CUPS).
  *
@@ -90,8 +90,8 @@ print_device(const char *uri,		/* I - Device URI */
 
     use_bc = strcasecmp(hostname, "Brother") &&
              strcasecmp(hostname, "Canon") &&
-             strcasecmp(hostname, "Konica Minolta") &&
-             strcasecmp(hostname, "Minolta");
+             strncasecmp(hostname, "Konica", 6) &&
+             strncasecmp(hostname, "Minolta", 7);
 #endif /* __FreeBSD__ || __NetBSD__ || __OpenBSD__ || __DragonFly__ */
 
     if ((device_fd = open_device(uri, &use_bc)) == -1)
@@ -345,7 +345,7 @@ open_device(const char *uri,		/* I - Device URI */
     * Find the correct USB device...
     */
 
-    do
+    for (;;)
     {
       for (busy = 0, i = 0; i < 16; i ++)
       {
@@ -414,21 +414,11 @@ open_device(const char *uri,		/* I - Device URI */
       */
 
       if (busy)
-      {
 	_cupsLangPuts(stderr,
 	              _("INFO: Printer busy; will retry in 5 seconds...\n"));
-	sleep(5);
-      }
+
+      sleep(5);
     }
-    while (busy);
-
-   /*
-    * Couldn't find the printer, return "no such device or address"...
-    */
-
-    errno = ENODEV;
-
-    return (-1);
   }
 #elif defined(__sun) && defined(ECPPIOC_GETDEVID)
   {
@@ -525,7 +515,7 @@ open_device(const char *uri,		/* I - Device URI */
   }
 #else
   {
-    if (use_bc)
+    if (*use_bc)
       fd = open(uri + 4, O_RDWR | O_EXCL);
     else
       fd = -1;
@@ -615,5 +605,5 @@ side_cb(int print_fd,			/* I - Print file */
 
 
 /*
- * End of "$Id: usb-unix.c 6911 2007-09-04 20:35:08Z mike $".
+ * End of "$Id: usb-unix.c 7406 2008-03-26 16:02:45Z mike $".
  */
