@@ -1,29 +1,17 @@
 /*
- * "$Id: adminutil.c 6262 2007-02-11 16:59:33Z mike $"
+ * "$Id: adminutil.c 7413 2008-03-31 22:02:59Z mike $"
  *
  *   Administration utility API definitions for the Common UNIX Printing
  *   System (CUPS).
  *
- *   MANY OF THE FUNCTIONS IN THIS HEADER ARE PRIVATE AND SUBJECT TO
- *   CHANGE AT ANY TIME.  USE AT YOUR OWN RISK.
- *
+ *   Copyright 2007-2008 by Apple Inc.
  *   Copyright 2001-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
- *   property of Easy Software Products and are protected by Federal
- *   copyright law.  Distribution and use rights are outlined in the file
- *   "LICENSE.txt" which should have been included with this file.  If this
- *   file is missing or damaged please contact Easy Software Products
- *   at:
- *
- *       Attn: CUPS Licensing Information
- *       Easy Software Products
- *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636 USA
- *
- *       Voice: (301) 373-9600
- *       EMail: cups-info@cups.org
- *         WWW: http://www.cups.org
+ *   property of Apple Inc. and are protected by Federal copyright
+ *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
+ *   which should have been included with this file.  If this file is
+ *   file is missing or damaged, see the license at "http://www.cups.org/".
  *
  *   This file is subject to the Apple OS-Developed Software exception.
  *
@@ -31,8 +19,10 @@
  *
  *   cupsAdminCreateWindowsPPD()   - Create the Windows PPD file for a printer.
  *   cupsAdminExportSamba()        - Export a printer to Samba.
- *   _cupsAdminGetServerSettings() - Get settings from the server.
- *   _cupsAdminSetServerSettings() - Set settings on the server.
+ *   cupsAdminGetServerSettings()  - Get settings from the server.
+ *   _cupsAdminGetServerSettings() - Get settings from the server (private).
+ *   cupsAdminSetServerSettings()  - Set settings on the server.
+ *   _cupsAdminSetServerSettings() - Set settings on the server (private).
  *   do_samba_command()            - Do a SAMBA command.
  *   get_cupsd_conf()              - Get the current cupsd.conf file.
  *   invalidate_cupsd_cache()      - Invalidate the cached cupsd.conf settings.
@@ -60,6 +50,12 @@
  * Local functions...
  */
 
+extern int		_cupsAdminGetServerSettings(http_t *http,
+				                    int *num_settings,
+			                            cups_option_t **settings);
+extern int		_cupsAdminSetServerSettings(http_t *http,
+			                            int num_settings,
+			                            cups_option_t *settings);
 static int		do_samba_command(const char *command,
 			                 const char *address,
 			                 const char *subcommand,
@@ -103,6 +99,7 @@ cupsAdminCreateWindowsPPD(
 			option[41],	/* Option */
 			choice[41];	/* Choice */
   int			jcloption,	/* In a JCL option? */
+			jclorder,	/* Next JCL order dependency */
 			linenum;	/* Current line number */
   time_t		curtime;	/* Current time */
   struct tm		*curdate;	/* Current date */
@@ -200,6 +197,7 @@ cupsAdminCreateWindowsPPD(
   */
 
   jcloption = 0;
+  jclorder  = 0;
   linenum   = 0;
   language  = cupsLangDefault();
 
@@ -238,10 +236,23 @@ cupsAdminCreateWindowsPPD(
       jcloption = 0;
       cupsFilePrintf(dstfp, "%s\n", line);
     }
+    else if (jcloption && !strncmp(line, "*OrderDependency:", 17))
+    {
+      for (ptr = line + 17; *ptr && isspace(*ptr & 255); ptr ++);
+
+      ptr = strchr(ptr, ' ');
+
+      if (ptr)
+      {
+	cupsFilePrintf(dstfp, "*OrderDependency: %d%s\n", jclorder, ptr);
+	jclorder ++;
+      }
+      else
+        cupsFilePrintf(dstfp, "%s\n", line);
+    }
     else if (jcloption &&
              strncmp(line, "*End", 4) &&
-             strncmp(line, "*Default", 8) &&
-             strncmp(line, "*OrderDependency", 16))
+             strncmp(line, "*Default", 8))
     {
       if ((ptr = strchr(line, ':')) == NULL)
       {
@@ -280,7 +291,7 @@ cupsAdminCreateWindowsPPD(
 	return (NULL);
       }
 
-      if (sscanf(line, "*%40s%*[ \t]%40[^/]", option, choice) != 2)
+      if (sscanf(line, "*%40s%*[ \t]%40[^:/]", option, choice) != 2)
       {
         snprintf(line, sizeof(line),
 	         _cupsLangString(language,
@@ -358,24 +369,24 @@ cupsAdminCreateWindowsPPD(
                                   IPP_TAG_ZERO)) != NULL &&
       (suppattr = ippFindAttribute(response, "job-hold-until-supported",
                                    IPP_TAG_ZERO)) != NULL)
-    write_option(dstfp, 10, "cupsJobHoldUntil", "Hold Until", "job-hold-until",
-                 suppattr, defattr, 0, 1);
+    write_option(dstfp, jclorder ++, "cupsJobHoldUntil", "Hold Until",
+                 "job-hold-until", suppattr, defattr, 0, 1);
 
   if ((defattr = ippFindAttribute(response, "job-priority-default",
                                   IPP_TAG_INTEGER)) != NULL &&
       (suppattr = ippFindAttribute(response, "job-priority-supported",
                                    IPP_TAG_RANGE)) != NULL)
-    write_option(dstfp, 11, "cupsJobPriority", "Priority", "job-priority",
-                 suppattr, defattr, 0, 1);
+    write_option(dstfp, jclorder ++, "cupsJobPriority", "Priority",
+                 "job-priority", suppattr, defattr, 0, 1);
 
   if ((defattr = ippFindAttribute(response, "job-sheets-default",
                                   IPP_TAG_ZERO)) != NULL &&
       (suppattr = ippFindAttribute(response, "job-sheets-supported",
                                    IPP_TAG_ZERO)) != NULL)
   {
-    write_option(dstfp, 20, "cupsJobSheetsStart", "Start Banner",
+    write_option(dstfp, jclorder ++, "cupsJobSheetsStart", "Start Banner",
                  "job-sheets", suppattr, defattr, 0, 2);
-    write_option(dstfp, 21, "cupsJobSheetsEnd", "End Banner",
+    write_option(dstfp, jclorder ++, "cupsJobSheetsEnd", "End Banner",
                  "job-sheets", suppattr, defattr, 1, 2);
   }
 
@@ -572,6 +583,10 @@ cupsAdminExportSamba(
     }
   }
 
+ /*
+  * See if we have the Win9x PS driver...
+  */
+
   snprintf(file, sizeof(file), "%s/drivers/ADOBEPS4.DRV", cg->cups_datadir);
   if (!access(file, 0))
   {
@@ -642,6 +657,136 @@ cupsAdminExportSamba(
     }
   }
 
+ /*
+  * See if we have the 64-bit Windows PS driver...
+  *
+  * Files:
+  *
+  *     x64/ps5ui.dll
+  *     x64/pscript.hlp
+  *     x64/pscript.ntf
+  *     x64/pscript5.dll
+  */
+
+  snprintf(file, sizeof(file), "%s/drivers/x64/pscript5.dll", cg->cups_datadir);
+  if (!access(file, 0))
+  {
+    have_drivers |= 4;
+
+   /*
+    * 64-bit Windows driver is installed; do the smbclient commands needed
+    * to copy the Win64 drivers over...
+    */
+
+    snprintf(address, sizeof(address), "//%s/print$", samba_server);
+
+    snprintf(subcmd, sizeof(subcmd),
+             "mkdir x64;"
+	     "put %s x64/%s.ppd;"
+	     "put %s/drivers/x64/ps5ui.dll x64/ps5ui.dll;"
+	     "put %s/drivers/x64/pscript.hlp x64/pscript.hlp;"
+	     "put %s/drivers/x64/pscript.ntf x64/pscript.ntf;"
+	     "put %s/drivers/x64/pscript5.dll x64/pscript5.dll",
+	     ppd, dest, cg->cups_datadir, cg->cups_datadir,
+	     cg->cups_datadir, cg->cups_datadir);
+
+    if ((status = do_samba_command("smbclient", address, subcmd,
+                                   authfile, logfile)) != 0)
+    {
+      snprintf(message, sizeof(message),
+               _cupsLangString(language,
+	                       _("Unable to copy 64-bit Windows printer "
+	                         "driver files (%d)!")), status);
+
+      _cupsSetError(IPP_INTERNAL_ERROR, message);
+
+      if (logfile)
+	_cupsLangPrintf(logfile, "%s\n", message);
+
+      unlink(authfile);
+
+      return (0);
+    }
+
+   /*
+    * See if we also have the CUPS driver files; if so, use them!
+    */
+
+    snprintf(file, sizeof(file), "%s/drivers/x64/cupsps6.dll", cg->cups_datadir);
+    if (!access(file, 0))
+    {
+     /*
+      * Copy the CUPS driver files over...
+      */
+
+      snprintf(subcmd, sizeof(subcmd),
+               "put %s/drivers/x64/cups6.ini x64/cups6.ini;"
+               "put %s/drivers/x64/cupsps6.dll x64/cupsps6.dll;"
+	       "put %s/drivers/x64/cupsui6.dll x64/cupsui6.dll",
+	       cg->cups_datadir, cg->cups_datadir, cg->cups_datadir);
+
+      if ((status = do_samba_command("smbclient", address, subcmd,
+                                     authfile, logfile)) != 0)
+      {
+	snprintf(message, sizeof(message),
+        	 _cupsLangString(language,
+	                         _("Unable to copy 64-bit CUPS printer driver "
+				   "files (%d)!")), status);
+
+	_cupsSetError(IPP_INTERNAL_ERROR, message);
+
+	if (logfile)
+	  _cupsLangPrintf(logfile, "%s\n", message);
+
+        unlink(authfile);
+
+	return (0);
+      }
+      
+     /*
+      * Do the rpcclient command needed for the CUPS drivers...
+      */
+
+      snprintf(subcmd, sizeof(subcmd),
+               "adddriver \"Windows x64\" \"%s:"
+	       "pscript5.dll:%s.ppd:ps5ui.dll:pscript.hlp:NULL:RAW:"
+	       "pscript5.dll,%s.ppd,ps5ui.dll,pscript.hlp,pscript.ntf,"
+	       "cups6.ini,cupsps6.dll,cupsui6.dll\"",
+	       dest, dest, dest);
+    }
+    else
+    {
+     /*
+      * Don't have the CUPS drivers, so just use the standard Windows
+      * drivers...
+      */
+
+      snprintf(subcmd, sizeof(subcmd),
+               "adddriver \"Windows x64\" \"%s:"
+	       "pscript5.dll:%s.ppd:ps5ui.dll:pscript.hlp:NULL:RAW:"
+	       "pscript5.dll,%s.ppd,ps5ui.dll,pscript.hlp,pscript.ntf\"",
+	       dest, dest, dest);
+    }
+
+    if ((status = do_samba_command("rpcclient", samba_server, subcmd,
+                                   authfile, logfile)) != 0)
+    {
+      snprintf(message, sizeof(message),
+               _cupsLangString(language,
+                	       _("Unable to install Windows 2000 printer "
+		        	 "driver files (%d)!")), status);
+
+      _cupsSetError(IPP_INTERNAL_ERROR, message);
+
+      if (logfile)
+	_cupsLangPrintf(logfile, "%s\n", message);
+
+      unlink(authfile);
+
+      return (0);
+    }
+  }
+
   if (logfile && !(have_drivers & 1))
   {
     if (!have_drivers)
@@ -656,12 +801,18 @@ cupsAdminExportSamba(
 				"are installed!")),
               sizeof(message));
 
-    _cupsSetError(IPP_INTERNAL_ERROR, message);
+    _cupsSetError(IPP_NOT_FOUND, message);
     _cupsLangPrintf(logfile, "%s\n", message);
   }
 
   if (have_drivers == 0)
+  {
+    _cupsSetError(IPP_NOT_FOUND, message);
+
+    unlink(authfile);
+
     return (0);
+  }
 
  /*
   * Finally, associate the drivers we just added with the queue...
@@ -693,6 +844,25 @@ cupsAdminExportSamba(
 }
 
 
+/*
+ * 'cupsAdminGetServerSettings()' - Get settings from the server.
+ *
+ * The returned settings should be freed with cupsFreeOptions() when
+ * you are done with them.
+ *
+ * @since CUPS 1.3@
+ */
+
+int					/* O - 1 on success, 0 on failure */
+cupsAdminGetServerSettings(
+    http_t        *http,		/* I - Connection to server */
+    int           *num_settings,	/* O - Number of settings */
+    cups_option_t **settings)		/* O - Settings */
+{
+  return (_cupsAdminGetServerSettings(http, num_settings, settings));
+}
+
+
 /*
  * '_cupsAdminGetServerSettings()' - Get settings from the server.
  *
@@ -768,6 +938,7 @@ _cupsAdminGetServerSettings(
 
     int		remote_access = 0,	/* Remote access allowed? */
 		remote_admin = 0,	/* Remote administration allowed? */
+		remote_any = 0,		/* Remote access from anywhere allowed? */
 		browsing = 1,		/* Browsing enabled? */
 		browse_allow = 1,	/* Browse address set? */
 		browse_address = 0,	/* Browse address set? */
@@ -787,8 +958,8 @@ _cupsAdminGetServerSettings(
 
     while (cupsFileGetConf(cupsd, line, sizeof(line), &value, &linenum))
     {
-      if (!value)
-        continue;
+      if (!value && strncmp(line, "</", 2))
+        value = line + strlen(line);
 
       if (!strcasecmp(line, "Port") || !strcasecmp(line, "Listen"))
       {
@@ -889,7 +1060,7 @@ _cupsAdminGetServerSettings(
 	in_admin_location = 0;
 	in_location       = 0;
       }
-      else if (!strcasecmp(line, "Allow") && in_admin_location &&
+      else if (!strcasecmp(line, "Allow") &&
                strcasecmp(value, "localhost") && strcasecmp(value, "127.0.0.1")
 #ifdef AF_LOCAL
 	       && *value != '/'
@@ -899,7 +1070,10 @@ _cupsAdminGetServerSettings(
 #endif /* AF_INET6 */
 	       )
       {
-	remote_admin = 1;
+        if (in_admin_location)
+	  remote_admin = 1;
+        else if (!strcasecmp(value, "all"))
+	  remote_any = 1;
       }
       else if (line[0] != '<' && !in_location && !in_policy)
         cg->cupsd_num_settings = cupsAddOption(line, value,
@@ -920,6 +1094,11 @@ _cupsAdminGetServerSettings(
 					   cg->cupsd_num_settings,
 					   &(cg->cupsd_settings));
 
+    cg->cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_ANY,
+                                           remote_any ? "1" : "0",
+					   cg->cupsd_num_settings,
+					   &(cg->cupsd_settings));
+
     cg->cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_PRINTERS,
                                            (browsing && browse_allow) ?
 					       "1" : "0",
@@ -957,6 +1136,22 @@ _cupsAdminGetServerSettings(
 }
 
 
+/*
+ * 'cupsAdminSetServerSettings()' - Set settings on the server.
+ *
+ * @since CUPS 1.3@
+ */
+
+int					/* O - 1 on success, 0 on failure */
+cupsAdminSetServerSettings(
+    http_t        *http,		/* I - Connection to server */
+    int           num_settings,		/* I - Number of settings */
+    cups_option_t *settings)		/* I - Settings */
+{
+  return (_cupsAdminSetServerSettings(http, num_settings, settings));
+}
+
+
 /*
  * '_cupsAdminSetServerSettings()' - Set settings on the server.
  *
@@ -992,6 +1187,7 @@ _cupsAdminSetServerSettings(
   int		remote_printers,	/* Show remote printers */
 		share_printers,		/* Share local printers */
 		remote_admin,		/* Remote administration allowed? */
+		remote_any,		/* Remote access from anywhere? */
 		user_cancel_any,	/* Cancel-job policy set? */
 		debug_logging;		/* LogLevel debug set? */
   int		wrote_port_listen,	/* Wrote the port/listen lines? */
@@ -1060,6 +1256,12 @@ _cupsAdminSetServerSettings(
   else
     old_remote_admin = 0;
 
+  if ((val = cupsGetOption(CUPS_SERVER_REMOTE_ANY, cupsd_num_settings,
+                           cupsd_settings)) != NULL)
+    remote_any = atoi(val);
+  else
+    remote_any = 0;
+
   if ((val = cupsGetOption(CUPS_SERVER_REMOTE_PRINTERS, cupsd_num_settings,
                            cupsd_settings)) != NULL)
     old_remote_printers = atoi(val);
@@ -1101,12 +1303,16 @@ _cupsAdminSetServerSettings(
   else
     debug_logging = -1;
 
+  if ((val = cupsGetOption(CUPS_SERVER_REMOTE_ANY, num_settings,
+                           settings)) != NULL)
+    remote_any = atoi(val);
+
   if ((val = cupsGetOption(CUPS_SERVER_REMOTE_ADMIN, num_settings,
                            settings)) != NULL)
   {
     remote_admin = atoi(val);
 
-    if (remote_admin == old_remote_admin)
+    if (remote_admin == old_remote_admin && remote_any < 0)
     {
      /*
       * No change to this setting...
@@ -1140,7 +1346,7 @@ _cupsAdminSetServerSettings(
   {
     share_printers = atoi(val);
 
-    if (share_printers == old_share_printers)
+    if (share_printers == old_share_printers && remote_any < 0)
     {
      /*
       * No change to this setting...
@@ -1260,14 +1466,21 @@ _cupsAdminSetServerSettings(
     {
       if (!wrote_browsing)
       {
+	int new_remote_printers = (remote_printers > 0 ||
+				   (remote_printers == -1 &&
+				    old_remote_printers > 0));
+	int new_share_printers = (share_printers > 0 ||
+				  (share_printers == -1 &&
+				   old_share_printers > 0));
+
         wrote_browsing = 1;
 
-        if (remote_printers > 0 || share_printers > 0)
+        if (new_remote_printers || new_share_printers)
 	{
-	  if (remote_printers > 0 && share_printers > 0)
+	  if (new_remote_printers && new_share_printers)
 	    cupsFilePuts(temp,
 	                 "# Enable printer sharing and shared printers.\n");
-	  else if (remote_printers > 0)
+	  else if (new_remote_printers)
 	    cupsFilePuts(temp,
 	                 "# Show shared printers on the local network.\n");
 	  else
@@ -1277,10 +1490,10 @@ _cupsAdminSetServerSettings(
 	  cupsFilePuts(temp, "Browsing On\n");
 	  cupsFilePuts(temp, "BrowseOrder allow,deny\n");
 
-	  if (remote_printers > 0)
-	    cupsFilePuts(temp, "BrowseAllow @LOCAL\n");
+	  if (new_remote_printers)
+	    cupsFilePuts(temp, "BrowseAllow all\n");
 
-	  if (share_printers > 0)
+	  if (new_share_printers)
 	    cupsFilePuts(temp, "BrowseAddress @LOCAL\n");
         }
 	else
@@ -1327,8 +1540,8 @@ _cupsAdminSetServerSettings(
 	                     "cancel a job...\n"
 	                     "  <Limit Cancel-Job>\n"
 	                     "    Order deny,allow\n"
-	                     "    Allow @SYSTEM\n"
-			     "    Allow @OWNER\n"
+			     "    Require user @OWNER "
+			     CUPS_DEFAULT_PRINTADMIN_AUTH "\n"
 			     "  </Limit>\n");
       }
 
@@ -1366,9 +1579,8 @@ _cupsAdminSetServerSettings(
         cupsFilePuts(temp, "  Order allow,deny\n");
 
 	if (remote_admin)
-	  cupsFilePuts(temp, "  Allow @LOCAL\n");
-	else
-	  cupsFilePuts(temp, "  Allow localhost\n");
+	  cupsFilePrintf(temp, "  Allow %s\n",
+	                 remote_any > 0 ? "all" : "@LOCAL");
       }
       else if (in_conf_location && remote_admin >= 0)
       {
@@ -1384,9 +1596,8 @@ _cupsAdminSetServerSettings(
         cupsFilePuts(temp, "  Order allow,deny\n");
 
 	if (remote_admin)
-	  cupsFilePuts(temp, "  Allow @LOCAL\n");
-	else
-	  cupsFilePuts(temp, "  Allow localhost\n");
+	  cupsFilePrintf(temp, "  Allow %s\n",
+	                 remote_any > 0 ? "all" : "@LOCAL");
       }
       else if (in_root_location && (remote_admin >= 0 || share_printers >= 0))
       {
@@ -1405,9 +1616,8 @@ _cupsAdminSetServerSettings(
         cupsFilePuts(temp, "  Order allow,deny\n");
 
 	if (remote_admin > 0 || share_printers > 0)
-	  cupsFilePuts(temp, "  Allow @LOCAL\n");
-	else
-	  cupsFilePuts(temp, "  Allow localhost\n");
+	  cupsFilePrintf(temp, "  Allow %s\n",
+	                 remote_any > 0 ? "all" : "@LOCAL");
       }
 
       in_admin_location = 0;
@@ -1477,7 +1687,8 @@ _cupsAdminSetServerSettings(
 	                   "a job...\n"
 	                   "  <Limit Cancel-Job>\n"
 	                   "    Order deny,allow\n"
-	                   "    Require user @OWNER @SYSTEM\n"
+	                   "    Require user @OWNER "
+			   CUPS_DEFAULT_PRINTADMIN_AUTH "\n"
 			   "  </Limit>\n");
 
       in_cancel_job = 0;
@@ -1485,7 +1696,8 @@ _cupsAdminSetServerSettings(
     else if ((((in_admin_location || in_conf_location || in_root_location) &&
                remote_admin >= 0) ||
               (in_root_location && share_printers >= 0)) &&
-             (!strcasecmp(line, "Allow") || !strcasecmp(line, "Deny") ||
+             (((!strcasecmp(line, "Allow") || !strcasecmp(line, "Deny")) &&
+	       !strcasecmp(value, "@LOCAL")) ||
 	      !strcasecmp(line, "Order")))
       continue;
     else if (in_cancel_job == 2)
@@ -1508,14 +1720,13 @@ _cupsAdminSetServerSettings(
       }
     }
     else if (!in_policy && !in_location &&
-             (val = cupsGetOption(line, num_settings, settings)) != NULL &&
-             !cupsGetOption(line, cupsd_num_settings, cupsd_settings))
+             (val = cupsGetOption(line, num_settings, settings)) != NULL)
     {
      /*
-      * Add this directive to the list of directives we have written...
+      * Replace this directive's value with the new one...
       */
 
-      cupsd_num_settings = cupsAddOption(line, value, cupsd_num_settings,
+      cupsd_num_settings = cupsAddOption(line, val, cupsd_num_settings,
                                          &cupsd_settings);
 
      /*
@@ -1523,7 +1734,7 @@ _cupsAdminSetServerSettings(
       * only support setting root directives, not in sections...
       */
 
-      cupsFilePrintf(temp, "%s %s\n", line, value);
+      cupsFilePrintf(temp, "%s %s\n", line, val);
     }
     else if (value)
     {
@@ -1564,7 +1775,7 @@ _cupsAdminSetServerSettings(
       cupsFilePuts(temp, "BrowseOrder allow,deny\n");
 
       if (remote_printers > 0)
-	cupsFilePuts(temp, "BrowseAllow @LOCAL\n");
+	cupsFilePuts(temp, "BrowseAllow all\n");
 
       if (share_printers > 0)
 	cupsFilePuts(temp, "BrowseAddress @LOCAL\n");
@@ -1626,9 +1837,7 @@ _cupsAdminSetServerSettings(
                        "  Order allow,deny\n");
 
     if (remote_admin > 0 || share_printers > 0)
-      cupsFilePuts(temp, "  Allow @LOCAL\n");
-    else
-      cupsFilePuts(temp, "  Allow localhost\n");
+      cupsFilePrintf(temp, "  Allow %s\n", remote_any > 0 ? "all" : "@LOCAL");
 
     cupsFilePuts(temp, "</Location>\n");
   }
@@ -1644,9 +1853,7 @@ _cupsAdminSetServerSettings(
                        "  Order allow,deny\n");
 
     if (remote_admin)
-      cupsFilePuts(temp, "  Allow @LOCAL\n");
-    else
-      cupsFilePuts(temp, "  Allow localhost\n");
+      cupsFilePrintf(temp, "  Allow %s\n", remote_any > 0 ? "all" : "@LOCAL");
 
     cupsFilePuts(temp, "</Location>\n");
   }
@@ -1660,14 +1867,12 @@ _cupsAdminSetServerSettings(
       cupsFilePuts(temp, "# Restrict access to the configuration files...\n");
 
     cupsFilePuts(temp, "<Location /admin/conf>\n"
-                       "  AuthType Basic\n"
+                       "  AuthType Default\n"
                        "  Require user @SYSTEM\n"
                        "  Order allow,deny\n");
 
     if (remote_admin)
-      cupsFilePuts(temp, "  Allow @LOCAL\n");
-    else
-      cupsFilePuts(temp, "  Allow localhost\n");
+      cupsFilePrintf(temp, "  Allow %s\n", remote_any > 0 ? "all" : "@LOCAL");
 
     cupsFilePuts(temp, "</Location>\n");
   }
@@ -1676,7 +1881,7 @@ _cupsAdminSetServerSettings(
   {
     cupsFilePuts(temp, "<Policy default>\n"
                        "  # Job-related operations must be done by the owner "
-		       "or an adminstrator...\n"
+		       "or an administrator...\n"
                        "  <Limit Send-Document Send-URI Hold-Job Release-Job "
 		       "Restart-Job Purge-Jobs Set-Job-Attributes "
 		       "Create-Job-Subscription Renew-Subscription "
@@ -1687,7 +1892,7 @@ _cupsAdminSetServerSettings(
                        "    Order deny,allow\n"
                        "  </Limit>\n"
                        "  # All administration operations require an "
-		       "adminstrator to authenticate...\n"
+		       "administrator to authenticate...\n"
 		       "  <Limit Pause-Printer Resume-Printer "
                        "Set-Printer-Attributes Enable-Printer "
 		       "Disable-Printer Pause-Printer-After-Current-Job "
@@ -1698,7 +1903,7 @@ _cupsAdminSetServerSettings(
 		       "CUPS-Add-Class CUPS-Delete-Class "
 		       "CUPS-Accept-Jobs CUPS-Reject-Jobs "
 		       "CUPS-Set-Default CUPS-Add-Device CUPS-Delete-Device>\n"
-                       "    AuthType Basic\n"
+                       "    AuthType Default\n"
 		       "    Require user @SYSTEM\n"
                        "    Order deny,allow\n"
                        "</Limit>\n");
@@ -1707,8 +1912,9 @@ _cupsAdminSetServerSettings(
       cupsFilePuts(temp, "  # Only the owner or an administrator can cancel "
                          "a job...\n"
 	                 "  <Limit Cancel-Job>\n"
-	                 "    Require user @OWNER @SYSTEM\n"
 	                 "    Order deny,allow\n"
+	                 "    Require user @OWNER "
+			 CUPS_DEFAULT_PRINTADMIN_AUTH "\n"
 			 "  </Limit>\n");
 
     cupsFilePuts(temp, "  <Limit All>\n"
@@ -1729,8 +1935,8 @@ _cupsAdminSetServerSettings(
                                          cupsd_num_settings, &cupsd_settings);
 
      /*
-      * Write the new value in its place, without indentation since we
-      * only support setting root directives, not in sections...
+      * Write the new value, without indentation since we only support
+      * setting root directives, not in sections...
       */
 
       cupsFilePrintf(temp, "%s %s\n", setting->name, setting->value);
@@ -1769,6 +1975,10 @@ _cupsAdminSetServerSettings(
                                 	 old_remote_admin ? "1" : "0",
 					 cupsd_num_settings, &cupsd_settings);
 
+    cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_ANY,
+                                       remote_any ? "1" : "0",
+				       cupsd_num_settings, &cupsd_settings);
+
     if (remote_printers >= 0)
       cupsd_num_settings = cupsAddOption(CUPS_SERVER_REMOTE_PRINTERS,
                                 	 remote_printers ? "1" : "0",
@@ -2128,5 +2338,5 @@ write_option(cups_file_t     *dstfp,	/* I - PPD file */
 
 
 /*
- * End of "$Id: adminutil.c 6262 2007-02-11 16:59:33Z mike $".
+ * End of "$Id: adminutil.c 7413 2008-03-31 22:02:59Z mike $".
  */
