@@ -1,9 +1,9 @@
 /*
- * "$Id: ppd.c 6942 2007-09-10 22:55:00Z mike $"
+ * "$Id: ppd.c 7222 2008-01-16 22:20:33Z mike $"
  *
  *   PPD file routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007 by Apple Inc.
+ *   Copyright 2007-2008 by Apple Inc.
  *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -454,6 +454,9 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
   cups_encoding_t	encoding;	/* Encoding of PPD file */
   _cups_globals_t	*cg = _cupsGlobals();
 					/* Global data */
+  char			custom_name[PPD_MAX_NAME];
+					/* CustomFoo attribute name */
+  ppd_attr_t		*custom_attr;	/* CustomFoo attribute */
   static const char * const ui_keywords[] =
 			{
 #ifdef CUPS_USE_FULL_UI_KEYWORDS_LIST
@@ -811,6 +814,13 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
         profile = realloc(ppd->profiles, sizeof(ppd_profile_t) *
 	                                 (ppd->num_profiles + 1));
 
+      if (!profile)
+      {
+        cg->ppd_status = PPD_ALLOC_ERROR;
+
+	goto error;
+      }
+
       ppd->profiles     = profile;
       profile           += ppd->num_profiles;
       ppd->num_profiles ++;
@@ -1005,44 +1015,14 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
     }
     else if (!strncmp(keyword, "Custom", 6) && !strcmp(name, "True") && !option)
     {
+      ppd_option_t	*custom_option;	/* Custom option */
+
       DEBUG_puts("Processing Custom option...");
 
      /*
       * Get the option and custom option...
       */
 
-      if ((option = ppdFindOption(ppd, keyword + 6)) == NULL)
-      {
-        int		groupidx = -1;	/* Index for current group */
-	ppd_group_t	*gtemp;		/* Temporary group */
-
-
-        DEBUG_printf(("%s option not found for %s...\n", keyword + 6, keyword));
-
-        if (group)
-          groupidx = group - ppd->groups; /* Save index for current group */
-
-	if ((gtemp = ppd_get_group(ppd, "General", _("General"), cg,
-	                           encoding)) == NULL)
-	{
-	  DEBUG_puts("Unable to get general group!");
-
-	  goto error;
-	}
-
-        if (group)
-          group = ppd->groups + groupidx; /* Restore group pointer */
-
-	if ((option = ppd_get_option(gtemp, keyword + 6)) == NULL)
-	{
-	  DEBUG_printf(("Unable to get %s option!\n", keyword + 6));
-
-          cg->ppd_status = PPD_ALLOC_ERROR;
-
-	  goto error;
-	}
-      }
-
       if (!ppd_get_coption(ppd, keyword + 6))
       {
         cg->ppd_status = PPD_ALLOC_ERROR;
@@ -1050,63 +1030,18 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 	goto error;
       }
 
-     /*
-      * Add the "custom" option...
-      */
+      if (option && !strcasecmp(option->keyword, keyword + 6))
+        custom_option = option;
+      else
+        custom_option = ppdFindOption(ppd, keyword + 6);
 
-      if ((choice = ppd_add_choice(option, "Custom")) == NULL)
+      if (custom_option)
       {
-	DEBUG_puts("Unable to add Custom choice!");
-
-        cg->ppd_status = PPD_ALLOC_ERROR;
-
-	goto error;
-      }
-
-      strlcpy(choice->text, text[0] ? text : _("Custom"),
-              sizeof(choice->text));
-
-      choice->code = string;
-      string       = NULL;		/* Don't add as an attribute below */
-      option       = NULL;
-
-     /*
-      * Now process custom page sizes specially...
-      */
-
-      if (!strcmp(keyword, "CustomPageSize"))
-      {
-	ppd->variable_sizes = 1;
-
        /*
-	* Add a "Custom" page size entry...
+	* Add the "custom" option...
 	*/
 
-	ppd_add_size(ppd, "Custom");
-
-	if ((option = ppdFindOption(ppd, "PageRegion")) == NULL)
-	{
-	  int		groupidx = -1;	/* Index to current group */
-	  ppd_group_t	*gtemp;		/* Temporary group */
-
-          if (group)
-            groupidx = group - ppd->groups; /* Save index for current group */
-
-	  if ((gtemp = ppd_get_group(ppd, "General", _("General"), cg,
-				     encoding)) == NULL)
-	  {
-	    DEBUG_puts("Unable to get general group!");
-
-	    goto error;
-	  }
-
-          if (group)
-            group = ppd->groups + groupidx; /* Restore group pointer */
-
-	  option = ppd_get_option(gtemp, "PageRegion");
-        }
-
-	if ((choice = ppd_add_choice(option, "Custom")) == NULL)
+	if ((choice = ppd_add_choice(custom_option, "Custom")) == NULL)
 	{
 	  DEBUG_puts("Unable to add Custom choice!");
 
@@ -1117,7 +1052,43 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 
 	strlcpy(choice->text, text[0] ? text : _("Custom"),
 		sizeof(choice->text));
-        option = NULL;
+
+	choice->code = strdup(string);
+      }
+
+     /*
+      * Now process custom page sizes specially...
+      */
+
+      if (!strcmp(keyword, "CustomPageSize"))
+      {
+       /*
+	* Add a "Custom" page size entry...
+	*/
+
+	ppd->variable_sizes = 1;
+
+	ppd_add_size(ppd, "Custom");
+
+	if (option && !strcasecmp(option->keyword, "PageRegion"))
+	  custom_option = option;
+	else
+	  custom_option = ppdFindOption(ppd, "PageRegion");
+
+        if (custom_option)
+	{
+	  if ((choice = ppd_add_choice(custom_option, "Custom")) == NULL)
+	  {
+	    DEBUG_puts("Unable to add Custom choice!");
+
+	    cg->ppd_status = PPD_ALLOC_ERROR;
+
+	    goto error;
+	  }
+
+	  strlcpy(choice->text, text[0] ? text : _("Custom"),
+		  sizeof(choice->text));
+        }
       }
     }
     else if (!strcmp(keyword, "LandscapeOrientation"))
@@ -1138,7 +1109,12 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 	}
 
       ppd->num_emulations = count;
-      ppd->emulations     = calloc(count, sizeof(ppd_emul_t));
+      if ((ppd->emulations = calloc(count, sizeof(ppd_emul_t))) == NULL)
+      {
+        cg->ppd_status = PPD_ALLOC_ERROR;
+
+	goto error;
+      }
 
       for (i = 0, sptr = string; i < count; i ++)
       {
@@ -1300,6 +1276,33 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 
       ppd_free(string);
       string = NULL;
+
+     /*
+      * Add a custom option choice if we have already seen a CustomFoo
+      * attribute...
+      */
+
+      if (!strcasecmp(name, "PageRegion"))
+        strcpy(custom_name, "CustomPageSize");
+      else
+        snprintf(custom_name, sizeof(custom_name), "Custom%s", name);
+
+      if ((custom_attr = ppdFindAttr(ppd, custom_name, "True")) != NULL)
+      {
+	if ((choice = ppd_add_choice(option, "Custom")) == NULL)
+	{
+	  DEBUG_puts("Unable to add Custom choice!");
+
+	  cg->ppd_status = PPD_ALLOC_ERROR;
+
+	  goto error;
+	}
+
+	strlcpy(choice->text,
+	        custom_attr->text[0] ? custom_attr->text : _("Custom"),
+		sizeof(choice->text));
+        choice->code = strdup(custom_attr->value);
+      }
     }
     else if (!strcmp(keyword, "JCLOpenUI"))
     {
@@ -1379,6 +1382,30 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
 
       ppd_free(string);
       string = NULL;
+
+     /*
+      * Add a custom option choice if we have already seen a CustomFoo
+      * attribute...
+      */
+
+      snprintf(custom_name, sizeof(custom_name), "Custom%s", name);
+
+      if ((custom_attr = ppdFindAttr(ppd, custom_name, "True")) != NULL)
+      {
+	if ((choice = ppd_add_choice(option, "Custom")) == NULL)
+	{
+	  DEBUG_puts("Unable to add Custom choice!");
+
+	  cg->ppd_status = PPD_ALLOC_ERROR;
+
+	  goto error;
+	}
+
+	strlcpy(choice->text,
+	        custom_attr->text[0] ? custom_attr->text : _("Custom"),
+		sizeof(choice->text));
+        choice->code = strdup(custom_attr->value);
+      }
     }
     else if (!strcmp(keyword, "CloseUI") || !strcmp(keyword, "JCLCloseUI"))
     {
@@ -1851,7 +1878,12 @@ ppdOpen2(cups_file_t *fp)		/* I - File to read from */
       * Add the option choice...
       */
 
-      choice = ppd_add_choice(option, name);
+      if ((choice = ppd_add_choice(option, name)) == NULL)
+      {
+        cg->ppd_status = PPD_ALLOC_ERROR;
+
+	goto error;
+      }
 
       if (text[0])
         cupsCharsetToUTF8((cups_utf8_t *)choice->text, text,
@@ -3186,5 +3218,5 @@ ppd_read(cups_file_t    *fp,		/* I - File to read from */
 
 
 /*
- * End of "$Id: ppd.c 6942 2007-09-10 22:55:00Z mike $".
+ * End of "$Id: ppd.c 7222 2008-01-16 22:20:33Z mike $".
  */
