@@ -1,25 +1,18 @@
 /*
- * "$Id: hpgl-main.c,v 1.23 2002/01/02 17:58:57 mike Exp $"
+ * "$Id: hpgl-main.c 6649 2007-07-11 21:46:42Z mike $"
  *
  *   HP-GL/2 filter main entry for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1993-2002 by Easy Software Products.
+ *   Copyright 2007 by Apple Inc.
+ *   Copyright 1993-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
- *   property of Easy Software Products and are protected by Federal
- *   copyright law.  Distribution and use rights are outlined in the file
- *   "LICENSE.txt" which should have been included with this file.  If this
- *   file is missing or damaged please contact Easy Software Products
- *   at:
+ *   property of Apple Inc. and are protected by Federal copyright
+ *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
+ *   which should have been included with this file.  If this file is
+ *   file is missing or damaged, see the license at "http://www.cups.org/".
  *
- *       Attn: CUPS Licensing Information
- *       Easy Software Products
- *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636-3111 USA
- *
- *       Voice: (301) 373-9603
- *       EMail: cups-info@cups.org
- *         WWW: http://www.cups.org
+ *   This file is subject to the Apple OS-Developed Software exception.
  *
  * Contents:
  *
@@ -34,6 +27,7 @@
 /*#define DEBUG*/
 #define _HPGL_MAIN_C_
 #include "hpgltops.h"
+#include <cups/i18n.h>
 
 
 /*
@@ -142,6 +136,7 @@ main(int  argc,		/* I - Number of command-line arguments */
   * Make sure status messages are not buffered...
   */
 
+  setbuf(stdout, NULL);
   setbuf(stderr, NULL);
 
  /*
@@ -150,7 +145,8 @@ main(int  argc,		/* I - Number of command-line arguments */
 
   if (argc < 6 || argc > 7)
   {
-    fputs("ERROR: hpgltops job-id user title copies options [file]\n", stderr);
+    fprintf(stderr, _("Usage: %s job-id user title copies options [file]\n"),
+            argv[0]);
     return (1);
   }
 
@@ -169,7 +165,7 @@ main(int  argc,		/* I - Number of command-line arguments */
 
     if ((fp = fopen(argv[6], "rb")) == NULL)
     {
-      perror("ERROR: unable to open print file - ");
+      perror("DEBUG: unable to open print file - ");
       return (1);
     }
   }
@@ -189,10 +185,14 @@ main(int  argc,		/* I - Number of command-line arguments */
   shading  = 1;
   PenWidth = 1.0;
 
-  if ((val = cupsGetOption("blackplot", num_options, options)) != NULL)
+  if ((val = cupsGetOption("blackplot", num_options, options)) != NULL &&
+      strcasecmp(val, "no") && strcasecmp(val, "off") &&
+      strcasecmp(val, "false"))
     shading = 0;
 
-  if ((val = cupsGetOption("fitplot", num_options, options)) != NULL)
+  if ((val = cupsGetOption("fitplot", num_options, options)) != NULL &&
+      strcasecmp(val, "no") && strcasecmp(val, "off") &&
+      strcasecmp(val, "false"))
     FitPlot = 1;
 
   if ((val = cupsGetOption("penwidth", num_options, options)) != NULL)
@@ -219,6 +219,8 @@ main(int  argc,		/* I - Number of command-line arguments */
 
   while ((num_params = ParseCommand(fp, name.name, &params)) >= 0)
   {
+    Outputf("%% %s(%d)\n", name.name, num_params);
+
 #ifdef DEBUG
     {
       int i;
@@ -261,5 +263,5 @@ compare_names(const void *p1,	/* I - First name */
 
 
 /*
- * End of "$Id: hpgl-main.c,v 1.23 2002/01/02 17:58:57 mike Exp $".
+ * End of "$Id: hpgl-main.c 6649 2007-07-11 21:46:42Z mike $".
  */
