@@ -1,25 +1,16 @@
 /*
- * "$Id: hpgl-vector.c,v 1.22 2005/01/03 19:29:57 mike Exp $"
+ * "$Id: hpgl-vector.c 6649 2007-07-11 21:46:42Z mike $"
  *
  *   HP-GL/2 vector routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1993-2005 by Easy Software Products.
+ *   Copyright 2007 by Apple Inc.
+ *   Copyright 1993-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
- *   property of Easy Software Products and are protected by Federal
- *   copyright law.  Distribution and use rights are outlined in the file
- *   "LICENSE.txt" which should have been included with this file.  If this
- *   file is missing or damaged please contact Easy Software Products
- *   at:
- *
- *       Attn: CUPS Licensing Information
- *       Easy Software Products
- *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636 USA
- *
- *       Voice: (301) 373-9600
- *       EMail: cups-info@cups.org
- *         WWW: http://www.cups.org
+ *   property of Apple Inc. and are protected by Federal copyright
+ *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
+ *   which should have been included with this file.  If this file is
+ *   file is missing or damaged, see the license at "http://www.cups.org/".
  *
  *   This file is subject to the Apple OS-Developed Software exception.
  *
@@ -635,7 +626,7 @@ decode_number(unsigned char **s,	/* IO - String to decode */
       else if (**s < 63)
       {
         if (**s != '\r' && **s != '\n')
-          fprintf(stderr, "ERROR: Bad PE character 0x%02X!\n", **s);
+          fprintf(stderr, "DEBUG: Bad PE character 0x%02X!\n", **s);
 
         continue;
       }
@@ -677,7 +668,7 @@ decode_number(unsigned char **s,	/* IO - String to decode */
       else if (**s < 63)
       {
         if (**s != '\r' && **s != '\n')
-          fprintf(stderr, "ERROR: Bad PE character 0x%02X!\n", **s);
+          fprintf(stderr, "DEBUG: Bad PE character 0x%02X!\n", **s);
 
         continue;
       }
@@ -771,5 +762,5 @@ plot_points(int     num_params,	/* I - Number of parameters */
 
 
 /*
- * End of "$Id: hpgl-vector.c,v 1.22 2005/01/03 19:29:57 mike Exp $".
+ * End of "$Id: hpgl-vector.c 6649 2007-07-11 21:46:42Z mike $".
  */
