@@ -1,9 +1,9 @@
 /*
- * "$Id: auth.c 6949 2007-09-12 21:33:23Z mike $"
+ * "$Id: auth.c 7384 2008-03-20 20:58:16Z mike $"
  *
  *   Authorization routines for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007 by Apple Inc.
+ *   Copyright 2007-2008 by Apple Inc.
  *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
  *   This file contains Kerberos support code, copyright 2006 by
@@ -176,8 +176,13 @@ cupsdAddLocation(const char *location)	/* I - Location path */
   * Initialize the record and copy the name over...
   */
 
-  temp->location = strdup(location);
-  temp->length   = strlen(temp->location);
+  if ((temp->location = strdup(location)) == NULL)
+  {
+    free(temp);
+    return (NULL);
+  }
+
+  temp->length = strlen(temp->location);
 
   cupsArrayAdd(Locations, temp);
 
@@ -257,7 +262,7 @@ cupsdAllowHost(cupsd_location_t *loc,	/* I - Location to add to */
     * Allow *interface*...
     */
 
-    temp->type             = AUTH_INTERFACE;
+    temp->type             = CUPSD_AUTH_INTERFACE;
     temp->mask.name.name   = strdup("*");
     temp->mask.name.length = 1;
   }
@@ -277,7 +282,7 @@ cupsdAllowHost(cupsd_location_t *loc,	/* I - Location to add to */
       *ifptr = '\0';
     }
 
-    temp->type             = AUTH_INTERFACE;
+    temp->type             = CUPSD_AUTH_INTERFACE;
     temp->mask.name.name   = strdup(ifname);
     temp->mask.name.length = ifptr - ifname;
   }
@@ -287,7 +292,7 @@ cupsdAllowHost(cupsd_location_t *loc,	/* I - Location to add to */
     * Allow name...
     */
 
-    temp->type             = AUTH_NAME;
+    temp->type             = CUPSD_AUTH_NAME;
     temp->mask.name.name   = strdup(name);
     temp->mask.name.length = strlen(name);
   }
@@ -300,9 +305,10 @@ cupsdAllowHost(cupsd_location_t *loc,	/* I - Location to add to */
  */
 
 void
-cupsdAllowIP(cupsd_location_t *loc,	/* I - Location to add to */
-             unsigned   address[4],	/* I - IP address to add */
-             unsigned   netmask[4])	/* I - Netmask of address */
+cupsdAllowIP(
+    cupsd_location_t *loc,		/* I - Location to add to */
+    const unsigned   address[4],	/* I - IP address to add */
+    const unsigned   netmask[4])	/* I - Netmask of address */
 {
   cupsd_authmask_t	*temp;		/* New host/domain mask */
 
@@ -316,7 +322,7 @@ cupsdAllowIP(cupsd_location_t *loc,	/* I - Location to add to */
   if ((temp = add_allow(loc)) == NULL)
     return;
 
-  temp->type = AUTH_IP;
+  temp->type = CUPSD_AUTH_IP;
   memcpy(temp->mask.ip.address, address, sizeof(temp->mask.ip.address));
   memcpy(temp->mask.ip.netmask, netmask, sizeof(temp->mask.ip.netmask));
 }
@@ -334,7 +340,7 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
   char		*ptr,			/* Pointer into string */
 		username[256],		/* Username string */
 		password[33];		/* Password string */
-  const char	*localuser;		/* Certificate username */
+  cupsd_cert_t	*localuser;		/* Certificate username */
   char		nonce[HTTP_MAX_VALUE],	/* Nonce value from client */
 		md5[33],		/* MD5 password */
 		basicmd5[33];		/* MD5 of Basic password */
@@ -363,14 +369,15 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
   */
 
   con->best = cupsdFindBest(con->uri, con->http.state);
+  con->type = CUPSD_AUTH_NONE;
 
   cupsdLogMessage(CUPSD_LOG_DEBUG2,
                   "cupsdAuthorize: con->uri=\"%s\", con->best=%p(%s)",
                   con->uri, con->best, con->best ? con->best->location : "");
 
-  if (con->best && con->best->type != AUTH_NONE)
+  if (con->best && con->best->type != CUPSD_AUTH_NONE)
   {
-    if (con->best->type == AUTH_DEFAULT)
+    if (con->best->type == CUPSD_AUTH_DEFAULT)
       type = DefaultAuthType;
     else
       type = con->best->type;
@@ -398,17 +405,7 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
   }
 #endif /* HAVE_AUTHORIZATION_H */
 
-  if (type == AUTH_NONE)
-  {
-   /*
-    * No authorization required, return early...
-    */
-
-    cupsdLogMessage(CUPSD_LOG_DEBUG,
-                    "cupsdAuthorize: No authentication required.");
-    return;
-  }
-  else if (!*authorization)
+  if (!*authorization)
   {
    /*
     * No authorization data provided, return early...
@@ -471,6 +468,8 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
 		    username);
 
     AuthorizationFreeItemSet(authinfo);
+
+    con->type = CUPSD_AUTH_BASIC;
   }
 #endif /* HAVE_AUTHORIZATION_H */
 #if defined(SO_PEERCRED) && defined(AF_LOCAL)
@@ -526,6 +525,8 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
     cupsdLogMessage(CUPSD_LOG_DEBUG,
                     "cupsdAuthorize: Authorized as %s using PeerCred",
 		    username);
+
+    con->type = CUPSD_AUTH_BASIC;
   }
 #endif /* SO_PEERCRED && AF_LOCAL */
   else if (!strncmp(authorization, "Local", 5) &&
@@ -541,7 +542,7 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
 
     if ((localuser = cupsdFindCert(authorization)) != NULL)
     {
-      strlcpy(username, localuser, sizeof(username));
+      strlcpy(username, localuser->username, sizeof(username));
 
       cupsdLogMessage(CUPSD_LOG_DEBUG,
 		      "cupsdAuthorize: Authorized as %s using Local",
@@ -554,9 +555,15 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
 		      "found!");
       return;
     }
+
+#ifdef HAVE_GSSAPI
+    if (localuser->ccache)
+      con->type = CUPSD_AUTH_NEGOTIATE;
+    else
+#endif /* HAVE_GSSAPI */
+      con->type = CUPSD_AUTH_BASIC;
   }
-  else if (!strncmp(authorization, "Basic", 5) &&
-           (type == AUTH_BASIC || type == AUTH_BASICDIGEST))
+  else if (!strncmp(authorization, "Basic", 5))
   {
    /*
     * Get the Basic authentication data...
@@ -615,7 +622,8 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
 
     switch (type)
     {
-      case AUTH_BASIC :
+      default :
+      case CUPSD_AUTH_BASIC :
           {
 #if HAVE_LIBPAM
 	   /*
@@ -656,7 +664,6 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
 	      cupsdLogMessage(CUPSD_LOG_ERROR,
 	                      "cupsdAuthorize: pam_start() returned %d (%s)!\n",
         	              pamerr, pam_strerror(pamh, pamerr));
-	      pam_end(pamh, 0);
 	      return;
 	    }
 
@@ -814,7 +821,7 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
 			  username);
           break;
 
-      case AUTH_BASICDIGEST :
+      case CUPSD_AUTH_BASICDIGEST :
          /*
 	  * Do Basic authentication with the Digest password file...
 	  */
@@ -842,8 +849,10 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
 			  username);
 	  break;
     }
+
+    con->type = type;
   }
-  else if (!strncmp(authorization, "Digest", 6) && type == AUTH_DIGEST)
+  else if (!strncmp(authorization, "Digest", 6))
   {
    /*
     * Get the username, password, and nonce from the Digest attributes...
@@ -915,6 +924,8 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
     cupsdLogMessage(CUPSD_LOG_DEBUG,
                     "cupsdAuthorize: Authorized as %s using Digest",
 		    username);
+
+    con->type = CUPSD_AUTH_DIGEST;
   }
 #ifdef HAVE_GSSAPI
   else if (!strncmp(authorization, "Negotiate", 9)) 
@@ -1054,30 +1065,23 @@ cupsdAuthorize(cupsd_client_t *con)	/* I - Client connection */
       gss_delete_sec_context(&minor_status, &context, GSS_C_NO_BUFFER);
 
       con->gss_have_creds = 1;
+
+      con->type = CUPSD_AUTH_NEGOTIATE;
     }
     else
       gss_release_name(&minor_status, &client_name);
   }
 #endif /* HAVE_GSSAPI */
-  else if (type != AUTH_NONE)
+  else
   {
     char	scheme[256];		/* Auth scheme... */
-    static const char * const types[] =	/* Auth types */
-    {
-      "None",
-      "Basic",
-      "Digest",
-      "BasicDigest",
-      "Negotiate"
-    };
 
 
     if (sscanf(authorization, "%255s", scheme) != 1)
       strcpy(scheme, "UNKNOWN");
 
-    cupsdLogMessage(CUPSD_LOG_ERROR,
-                    "Bad authentication data \"%s ...\", expected \"%s ...\"",
-                    scheme, types[type]);
+    cupsdLogMessage(CUPSD_LOG_ERROR, "Bad authentication data \"%s ...\"",
+                    scheme);
     return;
   }
 
@@ -1115,7 +1119,7 @@ cupsdCheckAuth(
   {
     switch (masks->type)
     {
-      case AUTH_INTERFACE :
+      case CUPSD_AUTH_INTERFACE :
          /*
 	  * Check for a match with a network interface...
 	  */
@@ -1223,7 +1227,7 @@ cupsdCheckAuth(
 	  }
 	  break;
 
-      case AUTH_NAME :
+      case CUPSD_AUTH_NAME :
          /*
 	  * Check for exact name match...
 	  */
@@ -1242,7 +1246,7 @@ cupsdCheckAuth(
 	    return (1);
           break;
 
-      case AUTH_IP :
+      case CUPSD_AUTH_IP :
          /*
 	  * Check for IP/network address match...
 	  */
@@ -1433,7 +1437,7 @@ cupsdCopyLocation(
     for (i = 0; i < temp->num_allow; i ++)
       switch (temp->allow[i].type = (*loc)->allow[i].type)
       {
-        case AUTH_NAME :
+        case CUPSD_AUTH_NAME :
 	    temp->allow[i].mask.name.length = (*loc)->allow[i].mask.name.length;
 	    temp->allow[i].mask.name.name   = strdup((*loc)->allow[i].mask.name.name);
 
@@ -1446,7 +1450,7 @@ cupsdCopyLocation(
 	      return (NULL);
 	    }
 	    break;
-	case AUTH_IP :
+	case CUPSD_AUTH_IP :
 	    memcpy(&(temp->allow[i].mask.ip), &((*loc)->allow[i].mask.ip),
 	           sizeof(cupsd_ipmask_t));
 	    break;
@@ -1471,7 +1475,7 @@ cupsdCopyLocation(
     for (i = 0; i < temp->num_deny; i ++)
       switch (temp->deny[i].type = (*loc)->deny[i].type)
       {
-        case AUTH_NAME :
+        case CUPSD_AUTH_NAME :
 	    temp->deny[i].mask.name.length = (*loc)->deny[i].mask.name.length;
 	    temp->deny[i].mask.name.name   = strdup((*loc)->deny[i].mask.name.name);
 
@@ -1484,7 +1488,7 @@ cupsdCopyLocation(
 	      return (NULL);
 	    }
 	    break;
-	case AUTH_IP :
+	case CUPSD_AUTH_IP :
 	    memcpy(&(temp->deny[i].mask.ip), &((*loc)->deny[i].mask.ip),
 	           sizeof(cupsd_ipmask_t));
 	    break;
@@ -1544,14 +1548,14 @@ cupsdDeleteLocation(
     free(loc->names);
 
   for (i = loc->num_allow, mask = loc->allow; i > 0; i --, mask ++)
-    if (mask->type == AUTH_NAME || mask->type == AUTH_INTERFACE)
+    if (mask->type == CUPSD_AUTH_NAME || mask->type == CUPSD_AUTH_INTERFACE)
       free(mask->mask.name.name);
 
   if (loc->num_allow > 0)
     free(loc->allow);
 
   for (i = loc->num_deny, mask = loc->deny; i > 0; i --, mask ++)
-    if (mask->type == AUTH_NAME || mask->type == AUTH_INTERFACE)
+    if (mask->type == CUPSD_AUTH_NAME || mask->type == CUPSD_AUTH_INTERFACE)
       free(mask->mask.name.name);
 
   if (loc->num_deny > 0)
@@ -1588,7 +1592,7 @@ cupsdDenyHost(cupsd_location_t *loc,	/* I - Location to add to */
     * Deny *interface*...
     */
 
-    temp->type             = AUTH_INTERFACE;
+    temp->type             = CUPSD_AUTH_INTERFACE;
     temp->mask.name.name   = strdup("*");
     temp->mask.name.length = 1;
   }
@@ -1608,7 +1612,7 @@ cupsdDenyHost(cupsd_location_t *loc,	/* I - Location to add to */
       *ifptr = '\0';
     }
 
-    temp->type             = AUTH_INTERFACE;
+    temp->type             = CUPSD_AUTH_INTERFACE;
     temp->mask.name.name   = strdup(ifname);
     temp->mask.name.length = ifptr - ifname;
   }
@@ -1618,7 +1622,7 @@ cupsdDenyHost(cupsd_location_t *loc,	/* I - Location to add to */
     * Deny name...
     */
 
-    temp->type             = AUTH_NAME;
+    temp->type             = CUPSD_AUTH_NAME;
     temp->mask.name.name   = strdup(name);
     temp->mask.name.length = strlen(name);
   }
@@ -1632,8 +1636,8 @@ cupsdDenyHost(cupsd_location_t *loc,	/* I - Location to add to */
 
 void
 cupsdDenyIP(cupsd_location_t *loc,	/* I - Location to add to */
-	    unsigned         address[4],/* I - IP address to add */
-	    unsigned         netmask[4])/* I - Netmask of address */
+	    const unsigned   address[4],/* I - IP address to add */
+	    const unsigned   netmask[4])/* I - Netmask of address */
 {
   cupsd_authmask_t	*temp;		/* New host/domain mask */
 
@@ -1647,7 +1651,7 @@ cupsdDenyIP(cupsd_location_t *loc,	/* I - Location to add to */
   if ((temp = add_deny(loc)) == NULL)
     return;
 
-  temp->type = AUTH_IP;
+  temp->type = CUPSD_AUTH_IP;
   memcpy(temp->mask.ip.address, address, sizeof(temp->mask.ip.address));
   memcpy(temp->mask.ip.netmask, netmask, sizeof(temp->mask.ip.netmask));
 }
@@ -1668,22 +1672,22 @@ cupsdFindBest(const char   *path,	/* I - Resource path */
 			*best;		/* Best match for location so far */
   int			bestlen;	/* Length of best match */
   int			limit;		/* Limit field */
-  static const int	limits[] =	/* Map http_status_t to AUTH_LIMIT_xyz */
+  static const int	limits[] =	/* Map http_status_t to CUPSD_AUTH_LIMIT_xyz */
 		{
-		  AUTH_LIMIT_ALL,
-		  AUTH_LIMIT_OPTIONS,
-		  AUTH_LIMIT_GET,
-		  AUTH_LIMIT_GET,
-		  AUTH_LIMIT_HEAD,
-		  AUTH_LIMIT_POST,
-		  AUTH_LIMIT_POST,
-		  AUTH_LIMIT_POST,
-		  AUTH_LIMIT_PUT,
-		  AUTH_LIMIT_PUT,
-		  AUTH_LIMIT_DELETE,
-		  AUTH_LIMIT_TRACE,
-		  AUTH_LIMIT_ALL,
-		  AUTH_LIMIT_ALL
+		  CUPSD_AUTH_LIMIT_ALL,
+		  CUPSD_AUTH_LIMIT_OPTIONS,
+		  CUPSD_AUTH_LIMIT_GET,
+		  CUPSD_AUTH_LIMIT_GET,
+		  CUPSD_AUTH_LIMIT_HEAD,
+		  CUPSD_AUTH_LIMIT_POST,
+		  CUPSD_AUTH_LIMIT_POST,
+		  CUPSD_AUTH_LIMIT_POST,
+		  CUPSD_AUTH_LIMIT_PUT,
+		  CUPSD_AUTH_LIMIT_PUT,
+		  CUPSD_AUTH_LIMIT_DELETE,
+		  CUPSD_AUTH_LIMIT_TRACE,
+		  CUPSD_AUTH_LIMIT_ALL,
+		  CUPSD_AUTH_LIMIT_ALL
 		};
 
 
@@ -1793,7 +1797,8 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
                   const char     *owner)/* I - Owner of object */
 {
   int			i, j,		/* Looping vars */
-			auth;		/* Authorization status */
+			auth,		/* Authorization status */
+			type;		/* Type of authentication */
   unsigned		address[4];	/* Authorization address */
   cupsd_location_t	*best;		/* Best match for location so far */
   int			hostlen;	/* Length of hostname */
@@ -1809,11 +1814,11 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
 		};
   static const char * const types[] =	/* Auth types */
 		{
-		  "NONE",
-		  "BASIC",
-		  "DIGEST",
-		  "BASICDIGEST",
-		  "KERBEROS"
+		  "None",
+		  "Basic",
+		  "Digest",
+		  "BasicDigest",
+		  "Negotiate"
 		};
 
 
@@ -1842,13 +1847,16 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
 
   best = con->best;
 
+  if ((type = best->type) == CUPSD_AUTH_DEFAULT)
+    type = DefaultAuthType;
+
   cupsdLogMessage(CUPSD_LOG_DEBUG2,
-                  "cupsdIsAuthorized: level=AUTH_%s, type=AUTH_%s, "
-		  "satisfy=AUTH_SATISFY_%s, num_names=%d",
-                  levels[best->level], types[best->type],
+                  "cupsdIsAuthorized: level=CUPSD_AUTH_%s, type=%s, "
+		  "satisfy=CUPSD_AUTH_SATISFY_%s, num_names=%d",
+                  levels[best->level], types[type],
 	          best->satisfy ? "ANY" : "ALL", best->num_names);
 
-  if (best->limit == AUTH_LIMIT_IPP)
+  if (best->limit == CUPSD_AUTH_LIMIT_IPP)
     cupsdLogMessage(CUPSD_LOG_DEBUG2, "cupsdIsAuthorized: op=%x(%s)",
                     best->op, ippOpString(best->op));
 
@@ -1892,7 +1900,7 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
     * Access from localhost (127.0.0.1 or ::1) is always allowed...
     */
 
-    auth = AUTH_ALLOW;
+    auth = CUPSD_AUTH_ALLOW;
   }
   else
   {
@@ -1903,39 +1911,39 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
     switch (best->order_type)
     {
       default :
-	  auth = AUTH_DENY;	/* anti-compiler-warning-code */
+	  auth = CUPSD_AUTH_DENY;	/* anti-compiler-warning-code */
 	  break;
 
-      case AUTH_ALLOW : /* Order Deny,Allow */
-          auth = AUTH_ALLOW;
+      case CUPSD_AUTH_ALLOW : /* Order Deny,Allow */
+          auth = CUPSD_AUTH_ALLOW;
 
           if (cupsdCheckAuth(address, con->http.hostname, hostlen,
 	          	best->num_deny, best->deny))
-	    auth = AUTH_DENY;
+	    auth = CUPSD_AUTH_DENY;
 
           if (cupsdCheckAuth(address, con->http.hostname, hostlen,
 	        	best->num_allow, best->allow))
-	    auth = AUTH_ALLOW;
+	    auth = CUPSD_AUTH_ALLOW;
 	  break;
 
-      case AUTH_DENY : /* Order Allow,Deny */
-          auth = AUTH_DENY;
+      case CUPSD_AUTH_DENY : /* Order Allow,Deny */
+          auth = CUPSD_AUTH_DENY;
 
           if (cupsdCheckAuth(address, con->http.hostname, hostlen,
 	        	best->num_allow, best->allow))
-	    auth = AUTH_ALLOW;
+	    auth = CUPSD_AUTH_ALLOW;
 
           if (cupsdCheckAuth(address, con->http.hostname, hostlen,
 	        	best->num_deny, best->deny))
-	    auth = AUTH_DENY;
+	    auth = CUPSD_AUTH_DENY;
 	  break;
     }
   }
 
-  cupsdLogMessage(CUPSD_LOG_DEBUG2, "cupsdIsAuthorized: auth=AUTH_%s...",
+  cupsdLogMessage(CUPSD_LOG_DEBUG2, "cupsdIsAuthorized: auth=CUPSD_AUTH_%s...",
                   auth ? "DENY" : "ALLOW");
 
-  if (auth == AUTH_DENY && best->satisfy == AUTH_SATISFY_ALL)
+  if (auth == CUPSD_AUTH_DENY && best->satisfy == CUPSD_AUTH_SATISFY_ALL)
     return (HTTP_FORBIDDEN);
 
 #ifdef HAVE_SSL
@@ -1945,9 +1953,9 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
 
   if ((best->encryption >= HTTP_ENCRYPT_REQUIRED && !con->http.tls &&
       strcasecmp(con->http.hostname, "localhost") &&
-      best->satisfy == AUTH_SATISFY_ALL) &&
-      !(best->type == AUTH_NEGOTIATE || 
-        (best->type == AUTH_NONE && DefaultAuthType == AUTH_NEGOTIATE)))
+      best->satisfy == CUPSD_AUTH_SATISFY_ALL) &&
+      !(type == CUPSD_AUTH_NEGOTIATE || 
+        (type == CUPSD_AUTH_NONE && DefaultAuthType == CUPSD_AUTH_NEGOTIATE)))
   {
     cupsdLogMessage(CUPSD_LOG_DEBUG,
                     "cupsdIsAuthorized: Need upgrade to TLS...");
@@ -1959,12 +1967,12 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
   * Now see what access level is required...
   */
 
-  if (best->level == AUTH_ANON ||	/* Anonymous access - allow it */
-      (best->type == AUTH_NONE && best->num_names == 0))
+  if (best->level == CUPSD_AUTH_ANON ||	/* Anonymous access - allow it */
+      (type == CUPSD_AUTH_NONE && best->num_names == 0))
     return (HTTP_OK);
 
-  if (!con->username[0] && best->type == AUTH_NONE &&
-      best->limit == AUTH_LIMIT_IPP)
+  if (!con->username[0] && type == CUPSD_AUTH_NONE &&
+      best->limit == CUPSD_AUTH_LIMIT_IPP)
   {
    /*
     * Check for unauthenticated username...
@@ -1981,7 +1989,7 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
                       attr->values[0].string.text);
       strlcpy(username, attr->values[0].string.text, sizeof(username));
     }
-    else if (best->satisfy == AUTH_SATISFY_ALL || auth == AUTH_DENY)
+    else if (best->satisfy == CUPSD_AUTH_SATISFY_ALL || auth == CUPSD_AUTH_DENY)
       return (HTTP_UNAUTHORIZED);	/* Non-anonymous needs user/pass */
     else
       return (HTTP_OK);			/* unless overridden with Satisfy */
@@ -1997,12 +2005,21 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
     if (!con->username[0])
 #endif /* HAVE_AUTHORIZATION_H */
     {
-      if (best->satisfy == AUTH_SATISFY_ALL || auth == AUTH_DENY)
+      if (best->satisfy == CUPSD_AUTH_SATISFY_ALL || auth == CUPSD_AUTH_DENY)
 	return (HTTP_UNAUTHORIZED);	/* Non-anonymous needs user/pass */
       else
 	return (HTTP_OK);		/* unless overridden with Satisfy */
     }
 
+    if (con->type != type && type != CUPSD_AUTH_NONE &&
+        (con->type != CUPSD_AUTH_BASIC || type != CUPSD_AUTH_BASICDIGEST))
+    {
+      cupsdLogMessage(CUPSD_LOG_ERROR, "Authorized using %s, expected %s!",
+                      types[con->type], types[type]);
+
+      return (HTTP_UNAUTHORIZED);
+    }
+
     strlcpy(username, con->username, sizeof(username));
   }
 
@@ -2043,7 +2060,7 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
   else
     pw = NULL;
 
-  if (best->level == AUTH_USER)
+  if (best->level == CUPSD_AUTH_USER)
   {
    /*
     * If there are no names associated with this location, then
@@ -2668,5 +2685,5 @@ to64(char          *s,			/* O - Output string */
 
 
 /*
- * End of "$Id: auth.c 6949 2007-09-12 21:33:23Z mike $".
+ * End of "$Id: auth.c 7384 2008-03-20 20:58:16Z mike $".
  */
