@@ -1,9 +1,9 @@
 /*
- * "$Id: cupsfilter.c 6816 2007-08-20 20:16:00Z mike $"
+ * "$Id: cupsfilter.c 7222 2008-01-16 22:20:33Z mike $"
  *
  *   CUPS filtering program for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 2007 by Apple Inc.
+ *   Copyright 2007-2008 by Apple Inc.
  *   Copyright 1997-2006 by Easy Software Products, all rights reserved.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -131,6 +131,7 @@ main(int  argc,				/* I - Number of command-line args */
 
   mime         = NULL;
   srctype      = NULL;
+  compression  = 0;
   dsttype      = "application/pdf";
   infile       = NULL;
   outfile      = NULL;
@@ -456,7 +457,8 @@ escape_options(
   for (i = num_options, option = options, bytes = 1; i > 0; i --, option ++)
     bytes += 2 * (strlen(option->name) + strlen(option->value)) + 2;
 
-  s = malloc(bytes);
+  if ((s = malloc(bytes)) == NULL)
+    return (NULL);
 
  /*
   * Copy the options to the string...
@@ -806,6 +808,8 @@ exec_filters(cups_array_t  *filters,	/* I - Array of filters to run */
     }
   }
 
+  cupsArrayDelete(pids);
+
   return (retval);
 }
 
@@ -992,5 +996,5 @@ usage(const char *command,		/* I - Command name */
 
 
 /*
- * End of "$Id: cupsfilter.c 6816 2007-08-20 20:16:00Z mike $".
+ * End of "$Id: cupsfilter.c 7222 2008-01-16 22:20:33Z mike $".
  */
