@@ -1,25 +1,16 @@
 /*
- * "$Id: lp.c 5926 2006-09-05 20:45:47Z mike $"
+ * "$Id: lp.c 6649 2007-07-11 21:46:42Z mike $"
  *
  *   "lp" command for the Common UNIX Printing System (CUPS).
  *
- *   Copyright 1997-2006 by Easy Software Products.
+ *   Copyright 2007 by Apple Inc.
+ *   Copyright 1997-2007 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
- *   property of Easy Software Products and are protected by Federal
- *   copyright law.  Distribution and use rights are outlined in the file
- *   "LICENSE.txt" which should have been included with this file.  If this
- *   file is missing or damaged please contact Easy Software Products
- *   at:
- *
- *       Attn: CUPS Licensing Information
- *       Easy Software Products
- *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636 USA
- *
- *       Voice: (301) 373-9600
- *       EMail: cups-info@cups.org
- *         WWW: http://www.cups.org
+ *   property of Apple Inc. and are protected by Federal copyright
+ *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
+ *   which should have been included with this file.  If this file is
+ *   file is missing or damaged, see the license at "http://www.cups.org/".
  *
  * Contents:
  *
@@ -290,7 +281,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 
 	      snprintf(email, sizeof(email), "mailto:%s@%s", cupsUser(),
 	               httpGetHostname(NULL, buffer, sizeof(buffer)));
-	      num_options = cupsAddOption("notify-recipient", email,
+	      num_options = cupsAddOption("notify-recipient-uri", email,
 	                                  num_options, &options);
 	    }
 
@@ -840,5 +831,5 @@ sighandler(int s)			/* I - Signal number */
 
 
 /*
- * End of "$Id: lp.c 5926 2006-09-05 20:45:47Z mike $".
+ * End of "$Id: lp.c 6649 2007-07-11 21:46:42Z mike $".
  */
